import asyncio
import logging
from aiohttp import ClientSession
from bot.api import telegram_api
from bot.config import FEEDBACK_CHAT_ID
from handlers.handle_join_request import handle_join_request, handle_reaction_on_request
from handlers.messages_routing import messages_routing

logging.basicConfig(level=logging.DEBUG)
logger = logging.getLogger('main')
state = dict()


async def main():
    logger.info("\tstarted")
    async with ClientSession() as session:
        offset = 0  # начальное значение offset
        while True:
            response = await telegram_api("getUpdates", offset=offset, allowed_updates=['message', 'edited_message', 'message_reaction','chat_join_request', 'chat_member'])
            if isinstance(response, dict):
                result = response.get("result", [])
                for update in result:
                    try:
                        message = update.get("message", update.get("edited_message"))
                        join_chat_request = update.get("join_chat_request")
                        message_reaction = update.get("join_chat_request")
                        if message:
                            await messages_routing(message, state)
                        elif join_chat_request:
                            await handle_join_request(join_chat_request)
                        elif message_reaction:
                            await handle_reaction_on_request(message_reaction)

                    except Exception as e:
                        logger.error(e)
                        import traceback
                        text = traceback.format_exc()
                        await telegram_api("sendMessage", chat_id=FEEDBACK_CHAT_ID, text=text)

                    offset = update["update_id"] + 1

                await asyncio.sleep(1.0)
            else:
                logger.error(' \n\n\n!!! getUpdates polling error\n\n\n')
                await asyncio.sleep(30.0)


if __name__ == "__main__":
    # Запуск асинхронного цикла
    asyncio.run(main())
